==> vmngclient-0.16.1.tar.gz: vmngclient-0.16.1/vmngclient/model/policy/definitions/data.py <==
# mypy: disable-error-code="empty-body"
from typing import List, Union

from pydantic import Field
from typing_extensions import Annotated

from vmngclient.model.policy.policy_definition import (
    AppListEntry,
    DefinitionSequence,
    DestinationDataIPv6PrefixListEntry,
    DestinationDataPrefixListEntry,
    DestinationIPEntry,
    DestinationPortEntry,
    DestinationRegionEntry,
    DNSAppListEntry,
    DNSEntry,
    DSCPEntry,
    PacketLengthEntry,
    PLPEntry,
    PolicyDefinitionBody,
    PolicyDefinitionHeader,
    ProtocolEntry,
    SourceDataIPv6PrefixListEntry,
    SourceDataPrefixListEntry,
    SourceIPEntry,
    SourcePortEntry,
    TCPEntry,
    TrafficToEntry,
)

DataPolicySequenceEntry = Annotated[
    Union[
        PacketLengthEntry,
        PLPEntry,
        ProtocolEntry,
        DSCPEntry,
        SourceIPEntry,
        SourcePortEntry,
        DestinationIPEntry,
        DestinationPortEntry,
        TCPEntry,
        DNSEntry,
        TrafficToEntry,
        SourceDataPrefixListEntry,
        DestinationDataPrefixListEntry,
        SourceDataIPv6PrefixListEntry,
        DestinationDataIPv6PrefixListEntry,
        DestinationRegionEntry,
        DNSAppListEntry,
        AppListEntry,
    ],
    Field(discriminator="field"),
]


class DataPolicy(PolicyDefinitionHeader):
    type: str = Field(default="data", const=True)


class DataPolicySequence(DefinitionSequence):
    type: str = Field(default="data", const=True)
    entries: List[DataPolicySequenceEntry]


class DataPolicyDefinition(PolicyDefinitionBody):
    sequences: List[DataPolicySequence] = []

==> vmngclient-0.17.3.dev0.tar.gz: vmngclient-0.17.3.dev0/vmngclient/model/policy/definitions/data.py <==
# mypy: disable-error-code="empty-body"
from typing import List, Union

from pydantic import Field
from typing_extensions import Annotated

from vmngclient.model.policy.policy_definition import (
    AppListEntry,
    DefinitionSequence,
    DestinationDataIPv6PrefixListEntry,
    DestinationDataPrefixListEntry,
    DestinationIPEntry,
    DestinationPortEntry,
    DestinationRegionEntry,
    DNSAppListEntry,
    DNSEntry,
    DSCPEntry,
    PacketLengthEntry,
    PLPEntry,
    PolicyDefinitionBody,
    PolicyDefinitionHeader,
    ProtocolEntry,
    SourceDataIPv6PrefixListEntry,
    SourceDataPrefixListEntry,
    SourceIPEntry,
    SourcePortEntry,
    TCPEntry,
    TrafficToEntry,
)

DataPolicySequenceEntry = Annotated[
    Union[
        PacketLengthEntry,
        PLPEntry,
        ProtocolEntry,
        DSCPEntry,
        SourceIPEntry,
        SourcePortEntry,
        DestinationIPEntry,
        DestinationPortEntry,
        TCPEntry,
        DNSEntry,
        TrafficToEntry,
        SourceDataPrefixListEntry,
        DestinationDataPrefixListEntry,
        SourceDataIPv6PrefixListEntry,
        DestinationDataIPv6PrefixListEntry,
        DestinationRegionEntry,
        DNSAppListEntry,
        AppListEntry,
    ],
    Field(discriminator="field"),
]


class DataPolicyHeader(PolicyDefinitionHeader):
    type: str = Field(default="data", const=True)


class DataPolicySequence(DefinitionSequence):
    type: str = Field(default="data", const=True)
    entries: List[DataPolicySequenceEntry]


class DataPolicyDefinition(PolicyDefinitionBody):
    sequences: List[DataPolicySequence] = []


class DataPolicy(DataPolicyHeader):
    type: str = Field(default="data", const=True)
